@@ -1,14 +1,10 @@
-#!/usr/bin/env python3
-# coding: utf8
-
-# Author: Lenz Furrer, 2017--2020
-
-
 """
 Loaders and formatters for BioC (XML and JSON).
 """
 
 
+__author__ = "Lenz Furrer"
+
 __all__ = ['BioCXMLLoader', 'BioCJSONLoader',
            'BioCXMLFormatter', 'BioCJSONFormatter']
 
@@ -75,8 +71,6 @@ class _BioCLoader(CollLoader, _OffsetMixin):
         """
         doc = Document(self._text(node, 'id', ifnone=None))
         doc.metadata = self.infon_dict(node)
-        doc.year = doc.metadata.pop('year', None)
-        doc.type = doc.metadata.pop('type', None)
 
         offset_mngr = self._offset_mngr()
         for passage in self._iterfind(node, 'passage'):
@@ -96,7 +90,7 @@ class _BioCLoader(CollLoader, _OffsetMixin):
     def _section(self, node, offset_mngr):
         """Get all relevant data from a passage node."""
         infon = self.infon_dict(node)
-        type_ = infon.pop('type', None)
+        type_ = infon.get('type')
         text = self._text(node)
         if text is None:
             # Text and annotations at sentence level.
@@ -223,7 +217,7 @@ class BioCJSONLoader(_BioCLoader):
         return text
 
 
-class BioCFormatter(Formatter):
+class _BioCFormatter(Formatter):
     """
     Base class for BioC formatting.
     """
@@ -235,7 +229,7 @@ class BioCFormatter(Formatter):
         self.metadata = metadata
 
 
-class BioCXMLFormatter(BioCFormatter, XMLMemoryFormatter, _OffsetMixin):
+class BioCXMLFormatter(_BioCFormatter, XMLMemoryFormatter, _OffsetMixin):
     """
     BioC XML output format.
     """
@@ -301,11 +295,6 @@ class BioCXMLFormatter(BioCFormatter, XMLMemoryFormatter, _OffsetMixin):
 
     def _document(self, doc):
         node = E('document', E('id', str(doc.id)))
-
-        if doc.year is not None:
-            self._infon(node, 'year', doc.year)
-        if doc.type is not None:
-            self._infon(node, 'type', doc.type)
         self._add_meta(node, doc.metadata)
 
         offset_mngr = self._offset_mngr()
@@ -316,8 +305,6 @@ class BioCXMLFormatter(BioCFormatter, XMLMemoryFormatter, _OffsetMixin):
 
     def _passage(self, section, offset_mngr):
         node = E('passage')
-        if section.type is not None:
-            self._infon(node, 'type', section.type)
         self._add_meta(node, section.metadata)
         node.append(E('offset', str(offset_mngr.passage(section))))
 
@@ -373,7 +360,7 @@ class BioCXMLFormatter(BioCFormatter, XMLMemoryFormatter, _OffsetMixin):
         node.append(E('infon', value, key=key))
 
 
-class BioCJSONFormatter(BioCFormatter, StreamFormatter, _OffsetMixin):
+class BioCJSONFormatter(_BioCFormatter, StreamFormatter, _OffsetMixin):
     """
     BioC JSON output format.
     """
@@ -402,23 +389,15 @@ class BioCJSONFormatter(BioCFormatter, StreamFormatter, _OffsetMixin):
     def _document(self, doc):
         offset_mngr = self._offset_mngr()
 
-        infons = dict(doc.metadata)
-        if doc.year is not None:
-            infons['year'] = doc.year
-        if doc.type is not None:
-            infons['type'] = doc.type
-
         return {
             'id': str(doc.id),
-            'infons': infons,
+            'infons': dict(doc.metadata),
             'passages': [self._passage(s, offset_mngr) for s in doc],
             'relations': (),
         }
 
     def _passage(self, section, offset_mngr):
         infons = dict(section.metadata)
-        if section.type is not None:
-            infons['type'] = section.type
         offset = offset_mngr.passage(section)
         text = ''         # empty for sentence-level anchoring
         annotations = []  # empty for sentence-level anchoring
